@@ -61,10 +61,10 @@ class GSPeerConnectionBroadcaster:
                     )
                 elif platform.system() == "Windows":
                     webcam = MediaPlayer(
-                        "video=Integrated Camera", format="dshow", options=options
+                        f"video=f{self.gsdbs.credentials['device']}", format="dshow", options=options
                     )
                 else:
-                    webcam = MediaPlayer("/dev/video0", format="v4l2", options=options)
+                    webcam = MediaPlayer(f"{self.gsdbs.credentials['device']}", format="v4l2", options=options)
                 relay = MediaRelay()
             return None, relay.subscribe(webcam.video)
 
